@@ -17,6 +17,8 @@
 from __future__ import print_function
 
 import argparse
+import io
+import locale
 import os
 import platform
 import sys
@@ -84,11 +86,14 @@ class Format(object):
         return line
 
 
-def show_problems(problems, file, args_format):
+def show_problems(problems, file, args_format, no_warn):
     max_level = 0
     first = True
 
     for problem in problems:
+        max_level = max(max_level, PROBLEM_LEVELS[problem.level])
+        if no_warn and (problem.level != 'error'):
+            continue
         if args_format == 'parsable':
             print(Format.parsable(problem, file))
         elif args_format == 'colored' or \
@@ -102,7 +107,6 @@ def show_problems(problems, file, args_format):
                 print(file)
                 first = False
             print(Format.standard(problem, file))
-        max_level = max(max_level, PROBLEM_LEVELS[problem.level])
 
     if not first and args_format != 'parsable':
         print('')
@@ -133,13 +137,19 @@ def run(argv=None):
                         action='store_true',
                         help='return non-zero exit code on warnings '
                              'as well as errors')
+    parser.add_argument('--no-warnings',
+                        action='store_true',
+                        help='output only error level problems')
     parser.add_argument('-v', '--version', action='version',
                         version='{} {}'.format(APP_NAME, APP_VERSION))
 
     args = parser.parse_args(argv)
 
+    if 'YAMLLINT_CONFIG_FILE' in os.environ:
+        user_global_config = os.path.expanduser(
+            os.environ['YAMLLINT_CONFIG_FILE'])
     # User-global config is supposed to be in ~/.config/yamllint/config
-    if 'XDG_CONFIG_HOME' in os.environ:
+    elif 'XDG_CONFIG_HOME' in os.environ:
         user_global_config = os.path.join(
             os.environ['XDG_CONFIG_HOME'], 'yamllint', 'config')
     else:
@@ -166,17 +176,21 @@ def run(argv=None):
         print(e, file=sys.stderr)
         sys.exit(-1)
 
+    if conf.locale is not None:
+        locale.setlocale(locale.LC_ALL, conf.locale)
+
     max_level = 0
 
     for file in find_files_recursively(args.files, conf):
         filepath = file[2:] if file.startswith('./') else file
         try:
-            with open(file) as f:
+            with io.open(file, newline='') as f:
                 problems = linter.run(f, conf, filepath)
         except EnvironmentError as e:
             print(e, file=sys.stderr)
             sys.exit(-1)
-        prob_level = show_problems(problems, file, args_format=args.format)
+        prob_level = show_problems(problems, file, args_format=args.format,
+                                   no_warn=args.no_warnings)
         max_level = max(max_level, prob_level)
 
     # read yaml from stdin
@@ -186,7 +200,8 @@ def run(argv=None):
         except EnvironmentError as e:
             print(e, file=sys.stderr)
             sys.exit(-1)
-        prob_level = show_problems(problems, 'stdin', args_format=args.format)
+        prob_level = show_problems(problems, 'stdin', args_format=args.format,
+                                   no_warn=args.no_warnings)
         max_level = max(max_level, prob_level)
 
     if max_level == PROBLEM_LEVELS['error']:
